@@ -1,5 +1,5 @@
 import contextlib, os, pathlib, subprocess, tempfile, unittest
-from job_lock import JobLock, jobinfo
+from job_lock import JobLock, JobLockAndWait, jobinfo
 
 class TestJobLock(unittest.TestCase, contextlib.ExitStack):
   def __init__(self, *args, **kwargs):
@@ -81,3 +81,30 @@ class TestJobLock(unittest.TestCase, contextlib.ExitStack):
       self.assertTrue(lock3)
     with JobLock(self.tmpdir/"lock4.lock") as lock4:
       self.assertTrue(lock4)
+
+  def testJobLockAndWait(self):
+    with JobLockAndWait(self.tmpdir/"lock1.lock", 0.001) as lock1:
+      self.assertEqual(lock1.niterations, 1)
+
+    with open(self.tmpdir/"lock2.lock", "w") as f:
+      f.write("SLURM 0 1234567")
+    with self.assertRaises(RuntimeError):
+      with JobLockAndWait(self.tmpdir/"lock2.lock", 0.001, maxiterations=10) as lock2:
+        pass
+
+    dummysqueue = """
+      #!/bin/bash
+      echo '
+             JOBID PARTITION     NAME     USER ST       TIME  NODES NODELIST(REASON)
+           1234567 partition    myjob       me  R   12:34:56      1 mynode
+      '
+      sed -i s/1234567/1234568/g $0
+    """.lstrip()
+    with open(self.tmpdir/"squeue", "w") as f:
+      f.write(dummysqueue)
+    (self.tmpdir/"squeue").chmod(0o0777)
+    os.environ["PATH"] = f"{self.tmpdir}:"+os.environ["PATH"]
+
+    with JobLockAndWait(self.tmpdir/"lock2.lock", 0.001, maxiterations=10) as lock2:
+      self.assertEqual(lock2.niterations, 2)
+
